<?php
// Copyright 2025 zenhp.co.jp
// 
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
// 
// http://www.apache.org/licenses/LICENSE-2.0
// 
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

// 基本設定
$log_file = 'setup_log.txt';
$setup_script = 'setup_flask.sh';

// クリーンアップ対象ファイル
$cleanup_files = [
    'setup.php',
    'setup_flask.sh',
    'setup_log.txt'
];

// スクリプト実行
if (isset($_POST['setup'])) {
    exec("bash $setup_script 2>&1", $output);
    file_put_contents($log_file, implode("\n", $output), FILE_APPEND);
    echo json_encode(['status' => 'completed']);
    exit;
}

// ログ取得用エンドポイント
if (isset($_GET['getlog'])) {
    if (file_exists($log_file)) {
        echo htmlspecialchars(file_get_contents($log_file));
    }
    exit;
}

// ファイル削除
if (isset($_POST['cleanup'])) {
    foreach ($cleanup_files as $file) {
        if (file_exists($file)) {
            unlink($file);
        }
    }
    header('Location: /');
    exit;
}

?>

<!DOCTYPE html>
<html lang="ja">
<head>
    <meta charset="UTF-8">
    <title>Flask環境セットアップ</title>
    <style>
        body {
            font-family: Arial, sans-serif;
            max-width: 800px;
            margin: 20px auto;
            padding: 0 20px;
        }
        .button {
            display: inline-block;
            padding: 10px 20px;
            margin: 10px;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            font-size: 16px;
        }
        .setup {
            background-color: #4CAF50;
            color: white;
        }
        .cleanup {
            background-color: #f44336;
            color: white;
        }
        .log {
            background-color: #f5f5f5;
            padding: 15px;
            border-radius: 5px;
            margin-top: 20px;
            white-space: pre-wrap;
            font-family: monospace;
        }
        .status {
            display: none;
            padding: 10px;
            margin: 10px 0;
            border-radius: 5px;
            background-color: #fff3cd;
            border: 1px solid #ffeeba;
        }
        .completed {
            background-color: #d4edda;
            border-color: #c3e6cb;
        }
        .disabled {
            opacity: 0.6;
            cursor: not-allowed;
        }
    </style>
</head>
<body>
    <h1>Flask環境セットアップマネージャー</h1>
    
    <form id="setupForm" method="post">
        <button type="submit" name="setup" id="setupButton" class="button setup">環境設定する</button>
        <button type="submit" name="cleanup" class="button cleanup" onclick="return confirm('本当にファイルを削除しますか？');">インストール用ファイルを削除する</button>
    </form>

    <div id="statusMessage" class="status">処理を実行中です...</div>
    <div id="completedMessage" class="status completed">セットアップが完了しました！</div>

    <div id="logContainer">
        <?php if (file_exists($log_file)): ?>
            <h2>実行ログ</h2>
            <div id="log" class="log">
                <?php echo htmlspecialchars(file_get_contents($log_file)); ?>
            </div>
        <?php endif; ?>
    </div>

    <script>
        document.getElementById('setupForm').addEventListener('submit', function(e) {
            if (e.submitter && e.submitter.name === 'setup') {
                e.preventDefault();
                const setupButton = document.getElementById('setupButton');
                const statusMessage = document.getElementById('statusMessage');
                const completedMessage = document.getElementById('completedMessage');
                const logContainer = document.getElementById('logContainer');
                const log = document.getElementById('log');

                // ボタンを無効化し、ステータスメッセージを表示
                setupButton.disabled = true;
                setupButton.classList.add('disabled');
                statusMessage.style.display = 'block';
                completedMessage.style.display = 'none';

                // セットアップ実行
                fetch('setup.php', {
                    method: 'POST',
                    body: new URLSearchParams({
                        'setup': '1'
                    })
                })
                .then(response => response.json())
                .then(data => {
                    if (data.status === 'completed') {
                        // 完了メッセージを表示
                        statusMessage.style.display = 'none';
                        completedMessage.style.display = 'block';
                        
                        // ログを更新
                        fetch('setup.php?getlog=1')
                        .then(response => response.text())
                        .then(logText => {
                            if (!log) {
                                logContainer.innerHTML = '<h2>実行ログ</h2><div id="log" class="log"></div>';
                            }
                            document.getElementById('log').textContent = logText;
                        });
                    }
                })
                .finally(() => {
                    // ボタンを再度有効化
                    setupButton.disabled = false;
                    setupButton.classList.remove('disabled');
                });
            }
        });
    </script>
</body>
</html>

